@@ -39,6 +39,7 @@ import java.io.IOException;
 
 import javax.xml.parsers.ParserConfigurationException;
 
+import org.junit.Ignore;
 import org.junit.Test;
 
 public class CDATATest extends AbstractHtmlCleanerTest {
@@ -60,9 +61,31 @@ public class CDATATest extends AbstractHtmlCleanerTest {
 		cleaner.getProperties().setOmitHtmlEnvelope(true);
 		assertCleaned(html, expected);
 		cleaner.getProperties().setOmitHtmlEnvelope(false);
-
 	}
 	
+	/**
+	 * Test for bug #211
+	 * This passes, but is marked @Ignore because it takes a while to run. Comment
+	 * out ignore and run this test before making any builds.
+	 * @throws Exception 
+	 */
+	@Ignore
+	@Test
+	public void UnclosedCDATA2() throws Exception{
+		String html = "<script><![CDATA[";
+		String x = "";
+		for (int i = 0; i < 513*1024; i++){x+="x";};
+		html += x;
+		html += "</script><p>Test</p>";
+		
+		String expected = "<script>/*<![CDATA[*/\n" + x + "\n/*]]>*/</script><p>Test</p>";
+		
+		cleaner.getProperties().setOmitHtmlEnvelope(true);
+		assertCleaned(html, expected);
+		cleaner.getProperties().setOmitHtmlEnvelope(false);
+	}
+	
+	
 	//
 	// Test for bug #185
 	//
