@@ -1,4 +1,4 @@
-/*  Copyright (c) 2006-2013, the HtmlCleaner Project
+/*  Copyright (c) 2006-2019, the HtmlCleaner Project
     All rights reserved.
 
     Redistribution and use of this software in source and binary forms,
@@ -51,6 +51,15 @@ import org.w3c.dom.Document;
 
 public class DomSerializerTest extends AbstractHtmlCleanerTest {
 	
+	@Test
+	public void removeInvalidTags3() throws Exception{
+	    String html="<p><^-^></p>";
+	    final TagNode tagNode = new HtmlCleaner().clean(html);
+        final CleanerProperties cleanerProperties = new CleanerProperties();
+        final Document doc = new DomSerializer(cleanerProperties).createDOM(tagNode);
+        assertEquals("&lt;^-^&gt;", doc.getElementsByTagName("p").item(0).getChildNodes().item(0).getTextContent());
+	}
+	
 	// See bug #203
 	@Test
 	public void parse2() throws Exception
